DRAM           .equ     $000000         ; First system RAM location
USERRAM        .equ     $004000         ; Beginning of non-reserved RAM
ENDRAM         .equ     $200000         ; End of DRAM
INITSTACK      .equ     ENDRAM-4        ; Good place to initialize stack

LEVEL0         .equ     $100            ; 68000 Level 0 Autovector Interrupt
USER0          .equ     $100            ; Pseudonym for LEVEL0

* Masks for INT1 CPU Interrupt Control Register

C_VIDENA       .equ     $0001           ; Enable Video time-base interrupts
C_GPUENA       .equ     $0002           ; Enable GPU register-write interrupt
C_OPENA        .equ     $0004           ; Enable OP stop-object interrupt
C_PITENA       .equ     $0008           ; Enable PIT interrupt
C_JERENA       .equ     $0010           ; Enable Jerry interrupt

C_VIDCLR       .equ     $0100           ; Clear pending video interrupts
C_GPUCLR       .equ     $0200           ; Clear pending GPU interrupts
C_OPCLR        .equ     $0400           ; Clear pending OP interrupts
C_PITCLR       .equ     $0800           ; Clear pending PIT interrupts
C_JERCLR       .equ     $1000           ; Clear pending Jerry interrupts


* JAGUAR REGISTERS

BASE           .equ     $F00000         ; TOM Internal Register Base

* TOM REGISTERS

HC             .equ     BASE+4  ; Horizontal Count
VC             .equ     BASE+6  ; Vertical Count
LPH            .equ     BASE+8  ; Horizontal Lightpen
LPV            .equ     BASE+$0A        ; Vertical Lightpen
OB0            .equ     BASE+$10        ; Current Object Phrase
OB1            .equ     BASE+$12
OB2            .equ     BASE+$14
OB3            .equ     BASE+$16
OLP            .equ     BASE+$20        ; Object List Pointer
OBF            .equ     BASE+$26        ; Object Processor Flag
VMODE          .equ     BASE+$28        ; Video Mode
BORD1          .equ     BASE+$2A        ; Border Color (Red & Green)
BORD2          .equ     BASE+$2C        ; Border Color (Blue)
HDB1           .equ     BASE+$38        ; Horizontal Display Begin One
HDB2           .equ     BASE+$3A        ; Horizontal Display Begin Two
HDE            .equ     BASE+$3C        ; Horizontal Display End
VS             .equ     BASE+$44        ; Vertical Sync
VDB            .equ     BASE+$46        ; Vertical Display Begin
VDE            .equ     BASE+$48        ; Vertical Display End
VI             .equ     BASE+$4E        ; Vertical Interrupt
PIT0           .equ     BASE+$50        ; Programmable Interrupt Timer (Lo)
PIT1           .equ     BASE+$52        ; Programmable Interrupt Timer (Hi)
BG             .equ     BASE+$58        ; Background Color

INT1           .equ     BASE+$E0        ; CPU Interrupt Control Register
INT2           .equ     BASE+$E2        ; CPU Interrupt Resume Register

CLUT           .equ     BASE+$400       ; Color Lookup Table

LBUFA          .equ     BASE+$800       ; Line Buffer A
LBUFB          .equ     BASE+$1000      ; Line Buffer B
LBUFC          .equ     BASE+$1800      ; Line Buffer Current

* OBJECT PROCESSOR.equATES

BITOBJ         .equ     0
SCBITOBJ       .equ     1
GPUOBJ         .equ     2
BRANCHOBJ      .equ     3
STOPOBJ        .equ     4

O_REFLECT      .equ     $00002000       ; OR with top LONG of BITMAP object
O_RMW          .equ     $00004000
O_TRANS        .equ     $00008000
O_RELEASE      .equ     $00010000

O_DEPTH1       .equ     (0<<12)         ; DEPTH Field for BITMAP objects
O_DEPTH2       .equ     (1<<12)
O_DEPTH4       .equ     (2<<12)
O_DEPTH8       .equ     (3<<12)
O_DEPTH16      .equ     (4<<12)
O_DEPTH32      .equ     (5<<12)

O_NOGAP        .equ     (1<<15)         ; Phrase GAP between image phrases
O_1GAP         .equ     (2<<15)
O_2GAP         .equ     (3<<15)
O_3GAP         .equ     (4<<15)
O_4GAP         .equ     (5<<15)
O_5GAP         .equ     (6<<15)
O_6GAP         .equ     (7<<15)

O_BREQ         .equ     (0<<14)         ; CC field of BRANCH objects
O_BRGT         .equ     (1<<14)
O_BRLT         .equ     (2<<14)
O_BROP         .equ     (3<<14)
O_BRHALF       .equ     (4<<14)

O_STOPINTS     .equ     $00000008       ; Enable Interrupts in STOP object

* VIDEO INITIALIZATION CONSTANTS

NTSC_WIDTH     .equ     1409            ; Width of screen in pixel clocks
NTSC_HMID      .equ     823             ; Middle of screen in pixel clocks
NTSC_HEIGHT    .equ     241             ; Height of screen in scanlines
NTSC_VMID      .equ     266             ; Middle of screen in halflines

PAL_WIDTH      .equ     1381            ;1381
PAL_HMID       .equ     803             ;843
PAL_HEIGHT     .equ     287             ;287
PAL_VMID       .equ     285             ;322

* The following mask will extract the PAL/NTSC flag bit from the
* CONFIG register. NTSC = Bit Set, PAL = Bit Clear

VIDTYPE        .equ     $10

* The following are Video Mode register flags

VIDEN          .equ     $0001           ; Enable video-time base generator

CRY16          .equ     $0000           ; Enable 16-bit CRY mode
RGB24          .equ     $0002           ; Enable 24-bit RGB mode
DIRECT16       .equ     $0004           ; Enable 16-bit DIRECT mode
RGB16          .equ     $0006           ; Enable 16-bit RGB mode

GENLOCK        .equ     $0008           ; Not Supported in Jaguar Console
INCEN          .equ     $0010           ; Enable encrustation
BINC           .equ     $0020           ; Select local border color
CSYNC          .equ     $0040           ; Enable composite sync
BGEN           .equ     $0080           ; Clear line buffer to BG
VARMOD         .equ     $0100           ; Enable variable-color resolution mode

PWIDTH1        .equ     $0000           ; Select pixels 1 clock wide
PWIDTH2        .equ     $0200           ; Select pixels 2 clocks wide
PWIDTH3        .equ     $0400           ; Select pixels 3 clocks wide
PWIDTH4        .equ     $0600           ; Select pixels 4 clocks wide
PWIDTH5        .equ     $0800           ; Select pixels 5 clocks wide
PWIDTH6        .equ     $0A00           ; Select pixels 6 clocks wide
PWIDTH7        .equ     $0C00           ; Select pixels 7 clocks wide
PWIDTH8        .equ     $0E00           ; Select pixels 8 clocks wide

* GPU REGISTERS

G_FLAGS        .equ     BASE+$2100      ; GPU Flags
G_MTXC         .equ     BASE+$2104      ; GPU Matrix Control
G_MTXA         .equ     BASE+$2108      ; GPU Matrix Address
G_END          .equ     BASE+$210C      ; GPU Data Organization
G_PC           .equ     BASE+$2110      ; GPU Program Counter
G_CTRL         .equ     BASE+$2114      ; GPU Operation Control/Status
G_HIDATA       .equ     BASE+$2118      ; GPU Bus Interface high data
G_REMAIN       .equ     BASE+$211C      ; GPU Division Remainder
G_DIVCTRL      .equ     BASE+$211C      ; GPU Divider control
G_RAM          .equ     BASE+$3000      ; GPU Internal RAM
G_ENDRAM       .equ     G_RAM +(4*1024) ; 4K bytes

* GPU Flags Register.equates

G_CPUENA       .equ     $00000010       ; CPU Interrupt enable bits
G_DSPENA       .equ     $00000020       ; DSP Interrupt enable bits
G_PITENA       .equ     $00000040       ; PIT Interrupt enable bits
G_OPENA        .equ     $00000080       ; Object Processor Interrupt enable bits
G_BLITENA      .equ     $00000100       ; Blitter Interrupt enable bits
G_CPUCLR       .equ     $00000200       ; CPU Interrupt clear bits
G_DSPCLR       .equ     $00000400       ; DSP Interrupt clear bits
G_PITCLR       .equ     $00000800       ; PIT Interrupt clear bits
G_OPCLR        .equ     $00001000       ; Object Processor Interrupt clear bits
G_BLITCLR      .equ     $00002000       ; Blitter Interrupt clear bits

* GPU Control/Status Register

GPUGO          .equ     $00000001       ; Start and Stop the GPU
GPUINT0        .equ     $00000004       ; generate a GPU type 0 interrupt

G_CPULAT       .equ     $00000040       ; Interrupt Latches
G_DSPLAT       .equ     $00000080
G_PITLAT       .equ     $00000100
G_OPLAT        .equ     $00000200
G_BLITLAT      .equ     $00000400

* BLITTER REGISTERS

A1_BASE        .equ     BASE+$2200      ; A1 Base Address
A1_FLAGS       .equ     BASE+$2204      ; A1 Control Flags
A1_CLIP        .equ     BASE+$2208      ; A1 Clipping Size
A1_PIXEL       .equ     BASE+$220C      ; A1 Pixel Pointer
A1_STEP        .equ     BASE+$2210      ; A1 Step (Integer Part)
A1_FSTEP       .equ     BASE+$2214      ; A1 Step (Fractional Part)
A1_FPIXEL      .equ     BASE+$2218      ; A1 Pixel Pointer (Fractional)
A1_INC         .equ     BASE+$221C      ; A1 Increment (Integer Part)
A1_FINC        .equ     BASE+$2220      ; A1 Increment (Fractional Part)
A2_BASE        .equ     BASE+$2224      ; A2 Base Address
A2_FLAGS       .equ     BASE+$2228      ; A2 Control Flags
A2_MASK        .equ     BASE+$222C      ; A2 Address Mask
A2_PIXEL       .equ     BASE+$2230      ; A2 PIXEL
A2_STEP        .equ     BASE+$2234      ; A2 Step (Integer)

B_CMD          .equ     BASE+$2238      ; Command
B_COUNT        .equ     BASE+$223C      ; Counters
B_SRCD         .equ     BASE+$2240      ; Source Data
B_DSTD         .equ     BASE+$2248      ; Destination Data
B_DSTZ         .equ     BASE+$2250      ; Destination Z
B_SRCZ1        .equ     BASE+$2258      ; Source Z (Integer)
B_SRCZ2        .equ     BASE+$2260      ; Source Z (Fractional)
B_PATD         .equ     BASE+$2268      ; Pattern Data
B_IINC         .equ     BASE+$2270      ; Intensity Increment
B_ZINC         .equ     BASE+$2274      ; Z Increment
B_STOP         .equ     BASE+$2278      ; Collision stop control

B_I3           .equ     BASE+$227C      ; Blitter Intensity 3
B_I2           .equ     BASE+$2280      ; Blitter Intensity 2
B_I1           .equ     BASE+$2284      ; Blitter Intensity 1
B_I0           .equ     BASE+$2288      ; Blitter Intensity 0

B_Z3           .equ     BASE+$228C      ; Blitter Z 3
B_Z2           .equ     BASE+$2290      ; Blitter Z 2
B_Z1           .equ     BASE+$2294      ; Blitter Z 1
B_Z0           .equ     BASE+$2298      ; Blitter Z 0

* BLITTER Command Register.equates

SRCEN          .equ     $00000001       ; d00:  source data read (inner loop)
SRCENZ         .equ     $00000002       ; d01:  source Z read (inner loop)
SRCENX         .equ     $00000004       ; d02:  source data read (realign)
DSTEN          .equ     $00000008       ; d03:  dest data read (inner loop)
DSTENZ         .equ     $00000010       ; d04:  dest Z read (inner loop)
DSTWRZ         .equ     $00000020       ; d05:  dest Z write (inner loop)
CLIP_A1        .equ     $00000040       ; d06:  A1 clipping enable
UPDA1F         .equ     $00000100       ; d08:  A1 update step fraction
UPDA1          .equ     $00000200       ; d09:  A1 update step
UPDA2          .equ     $00000400       ; d10:  A2 update step
DSTA2          .equ     $00000800       ; d11:  reverse usage of A1 and A2
GOURD          .equ     $00001000       ; d12:  enable Gouraud shading
ZBUFF          .equ     $00002000       ; d13:  polygon Z data updates
TOPBEN         .equ     $00004000       ; d14:  intensity carry into byte
TOPNEN         .equ     $00008000       ; d15:  intensity carry into nibble
PATDSEL        .equ     $00010000       ; d16:  Select pattern data
ADDDSEL        .equ     $00020000       ; d17:  diagnostic
                                        ; d18-d20: Z comparator inhibit
ZMODELT        .equ     $00040000       ;       source < destination
ZMODEEQ        .equ     $00080000       ;       source = destination
ZMODEGT        .equ     $00100000       ;       source > destination
                                        ; d21-d24: Logic function control
LFU_NAN        .equ     $00200000       ;       !source & !destination
LFU_NA         .equ     $00400000       ;       !source &  destination
LFU_AN         .equ     $00800000       ;       source & !destination
LFU_A          .equ     $01000000       ;       source &  destination

CMPDST         .equ     $02000000       ; d25:  pixel compare pattern & dest
BCOMPEN        .equ     $04000000       ; d26:  bit compare write inhibit
DCOMPEN        .equ     $08000000       ; d27:  data compare write inhibit
BKGWREN        .equ     $10000000       ; d28:  data write back
BUSHI          .equ     $20000000       ; d29   blitter priority
SRCSHADE       .equ     $40000000       ; d30:  shade src data w/IINC value

* The following are ALL 16 possible logical operations of the LFUs

LFU_ZERO       .equ     $00000000       ; All Zeros
LFU_NSAND      .equ     $00200000       ; NOT Source AND NOT Destination
LFU_NSAD       .equ     $00400000       ; NOT Source AND Destination
LFU_NOTS       .equ     $00600000       ; NOT Source
LFU_SAND       .equ     $00800000       ; Source AND NOT Destination
LFU_NOTD       .equ     $00A00000       ; NOT Destination
LFU_N_SXORD    .equ     $00C00000       ; NOT (Source XOR Destination)
LFU_NSORND     .equ     $00E00000       ; NOT Source OR NOT Destination
LFU_SAD        .equ     $01000000       ; Source AND Destination
LFU_SXORD      .equ     $01200000       ; Source XOR Destination
LFU_D          .equ     $01400000       ; Destination
LFU_NSORD      .equ     $01600000       ; NOT Source OR Destination
LFU_S          .equ     $01800000       ; Source
LFU_SORND      .equ     $01A00000       ; Source OR NOT Destination
LFU_SORD       .equ     $01C00000       ; Source OR Destination
LFU_ONE        .equ     $01E00000       ; All Ones

* These are some common combinations with less boolean names

LFU_REPLACE    .equ     $01800000       ; Source REPLACEs destination
LFU_XOR        .equ     $01200000       ; Source XOR with destination
LFU_CLEAR      .equ     $00000000       ; CLEAR destination

* BLITTER Flags (A1 or A2) register.equates

* Pitch d00-d01:
*       distance between pixel phrases
PITCH1         .equ     $00000000       ; 0 phrase gap
PITCH2         .equ     $00000001       ; 1 phrase gap
PITCH4         .equ     $00000002       ; 3 phrase gap
PITCH3         .equ     $00000003       ; 2 phrase gap

* Pixel d03-d05
*       bit depth (2^n)
PIXEL1         .equ     $00000000       ; n = 0
PIXEL2         .equ     $00000008       ; n = 1
PIXEL4         .equ     $00000010       ; n = 2
PIXEL8         .equ     $00000018       ; n = 3
PIXEL16        .equ     $00000020       ; n = 4
PIXEL32        .equ     $00000028       ; n = 5

* Z offset d06-d08
*       offset from phrase of pixel data from its corresponding
*       Z data phrases
ZOFFS0         .equ     $00000000       ; offset = 0    UNUSED
ZOFFS1         .equ     $00000040       ; offset = 1
ZOFFS2         .equ     $00000080       ; offset = 2
ZOFFS3         .equ     $000000C0       ; offset = 3
ZOFFS4         .equ     $00000100       ; offset = 4
ZOFFS5         .equ     $00000140       ; offset = 5
ZOFFS6         .equ     $00000180       ; offset = 6
ZOFFS7         .equ     $000001C0       ; offset = 7    UNUSED

* Width d09-d14
*       width used for address generation
*       This is a 6-bit floating point value in pixels
*       4-bit unsigned exponent
*       2-bit mantissa with implied 3rd bit of 1
WID2           .equ     $00000800       ; 1.00 X 2^1  ( 4<<9)
WID4           .equ     $00001000       ; 1.00 X 2^2  ( 8<<9)
WID6           .equ     $00001400       ; 1.10 X 2^2  (10<<9)
WID8           .equ     $00001800       ; 1.00 x 2^3  (12<<9)
WID10          .equ     $00001A00       ; 1.01 X 2^3  (13<<9)
WID12          .equ     $00001C00       ; 1.10 X 2^3  (14<<9)
WID14          .equ     $00001E00       ; 1.11 X 2^3  (15<<9)
WID16          .equ     $00002000       ; 1.00 X 2^4  (16<<9)
WID20          .equ     $00002200       ; 1.01 X 2^4  (17<<9)
WID24          .equ     $00002400       ; 1.10 X 2^4  (18<<9)
WID28          .equ     $00002600       ; 1.11 X 2^4  (19<<9)
WID32          .equ     $00002800       ; 1.00 X 2^5  (20<<9)
WID40          .equ     $00002A00       ; 1.01 X 2^5  (21<<9)
WID48          .equ     $00002C00       ; 1.10 X 2^5  (22<<9)
WID56          .equ     $00002E00       ; 1.11 X 2^5  (23<<9)
WID64          .equ     $00003000       ; 1.00 X 2^6  (24<<9)
WID80          .equ     $00003200       ; 1.01 X 2^6  (25<<9)
WID96          .equ     $00003400       ; 1.10 X 2^6  (26<<9)
WID112         .equ     $00003600       ; 1.11 X 2^6  (27<<9)
WID128         .equ     $00003800       ; 1.00 X 2^7  (28<<9)
WID160         .equ     $00003A00       ; 1.01 X 2^7  (29<<9)
WID192         .equ     $00003C00       ; 1.10 X 2^7  (30<<9)
WID224         .equ     $00003E00       ; 1.11 X 2^7  (31<<9)
WID256         .equ     $00004000       ; 1.00 X 2^8  (32<<9)
WID320         .equ     $00004200       ; 1.01 X 2^8  (33<<9)
WID384         .equ     $00004400       ; 1.10 X 2^8  (34<<9)
WID448         .equ     $00004600       ; 1.11 X 2^8  (35<<9)
WID512         .equ     $00004800       ; 1.00 X 2^9  (36<<9)
WID640         .equ     $00004A00       ; 1.01 X 2^9  (37<<9)
WID768         .equ     $00004C00       ; 1.10 X 2^9  (38<<9)
WID896         .equ     $00004E00       ; 1.11 X 2^9  (39<<9)
WID1024        .equ     $00005000       ; 1.00 X 2^10 (40<<9)
WID1280        .equ     $00005200       ; 1.01 X 2^10 (41<<9)
WID1536        .equ     $00005400       ; 1.10 X 2^10 (42<<9)
WID1792        .equ     $00005600       ; 1.11 X 2^10 (43<<9)
WID2048        .equ     $00005800       ; 1.00 X 2^11 (44<<9)
WID2560        .equ     $00005A00       ; 1.01 X 2^11 (45<<9)
WID3072        .equ     $00005C00       ; 1.10 X 2^11 (46<<9)
WID3584        .equ     $00005E00       ; 1.11 X 2^11 (47<<9)

* X add control d16-d17
*       controls the update of the X pointer on each pass
*       round the inner loop
XADDPHR        .equ     $00000000       ; 00 - add phrase width and truncate
XADDPIX        .equ     $00010000       ; 01 - add pixel size (add 1)
XADD0          .equ     $00020000       ; 10 - add zero
XADDINC        .equ     $00030000       ; 11 - add the increment

* Y add control d18
*       controls the update of the Y pointer within the inner loop.
*       it is overridden by the X add control if they are in add increment
YADD0          .equ     $00000000       ; 00 - add zero
YADD1          .equ     $00040000       ; 01 - add 1

* X sign d19
*       add or subtract pixel size if X add control = 01 (XADDPIX)
XSIGNADD       .equ     $00000000       ; 0 - add pixel size
XSIGNSUB       .equ     $00080000       ; 1 - subtract pixel size

* Y sign d20
*       add or subtract pixel size if Y add control = 01 (YADD1)
YSIGNADD       .equ     $00000000       ; 0 - add 1
YSIGNSUB       .equ     $00100000       ; 1 - sub 1


* JERRY REGISTERS
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

JPIT1          .equ     BASE+$10000     ; Timer 1 Pre-Scaler
JPIT2          .equ     BASE+$10002     ; Timer 1 Divider
JPIT3          .equ     BASE+$10004     ; Timer 2 Pre-Scaler
JPIT4          .equ     BASE+$10006     ; Timer 2 Divider

J_INT          .equ     BASE+$10020     ; Jerry Interrupt control (to TOM)

JOYSTICK       .equ     BASE+$14000     ; Joystick register and mute
JOYBUTS        .equ     BASE+$14002     ; Joystick register
CONFIG         .equ     BASE+$14002     ; Also has NTSC/PAL

MOD_MASK       .equ     BASE+$1A118     ; Mask for ADDQ(SUBQ)MOD

SCLK           .equ     BASE+$1A150     ; SSI Clock Frequency
SMODE          .equ     BASE+$1A154     ; SSI Control

L_I2S          .equ     BASE+$1A148     ; I2S Serial Interface
R_I2S          .equ     BASE+$1A14C     ; I2S Serial Interface

* Jerry Interrupt Control Flags

J_EXTENA       .equ     $0001           ; Enable external interrupts
J_DSPENA       .equ     $0002           ; Enable DSP interrupts
J_TIM1ENA      .equ     $0004           ; Enable Timer 1 interrupts
J_TIM2ENA      .equ     $0008           ; Enable Timer 2 interrupts
J_ASYNENA      .equ     $0010           ; Enable Asyncronous Serial interrupts
J_SYNENA       .equ     $0020           ; Enable Syncronous Serial interrupts

J_EXTCLR       .equ     $0100           ; Clear pending external interrupts
J_DSPCLR       .equ     $0200           ; Clear pending DSP interrupts
J_TIM1CLR      .equ     $0400           ; Clear pending Timer 1 interrupts
J_TIM2CLR      .equ     $0800           ; Clear pending Timer 2 interrupts
J_ASYNCLR      .equ     $1000           ; Clear pending Asynch. Serial interrupts
J_SYNCLR       .equ     $2000           ; Clear pending Synch. Serial interrupts

* JERRY Joystick.equates

* Bits when LONGword is formatted as below (from JOYTEST\JT_LOOP.S).
*
* Format: xxApxxBx RLDU147* xxCxxxox 2580369#

JOY_UP         .equ     20      ;joypad
JOY_DOWN       .equ     21
JOY_LEFT       .equ     22
JOY_RIGHT      .equ     23

FIRE_A         .equ     29      ;fire buttons
FIRE_B         .equ     25
FIRE_C         .equ     13
OPTION         .equ     9
PAUSE          .equ     28

KEY_STAR       .equ     16      ;keypad
KEY_7          .equ     17
KEY_4          .equ     18
KEY_1          .equ     19

KEY_0          .equ     4
KEY_8          .equ     5
KEY_5          .equ     6
KEY_2          .equ     7

KEY_HASH       .equ     0
KEY_9          .equ     1
KEY_6          .equ     2
KEY_3          .equ     3

ANY_JOY        .equ     $00F00000       ; AND joyedge with this...
                                ; joypad was pressed if result is not 0
ANY_FIRE       .equ     $32002200       ; AND joyedge with this...
                                ; A,B C, Option or Pause was pressed
                                ; if result is not 0
ANY_KEY        .equ     $000F00FF       ; AND joyedge with this... 123456789*0#
                                ; was pressed if result is not 0

* ROM Tables built into Jerry - 128 samples each
* 16 bit samples sign extended to 32

ROM_TABLE      .equ     BASE+$1D000     ; Base of tables

ROM_TRI        .equ     BASE+$1D000     ; A triangle wave
ROM_SINE       .equ     BASE+$1D200     ; Full amplitude SINE
ROM_AMSINE     .equ     BASE+$1D400     ; Linear (?) ramp SINE
ROM_12W        .equ     BASE+$1D600     ; SINE(X)+SINE(2*X) : (was ROM_SINE12W)
ROM_CHIRP16    .equ     BASE+$1D800     ; SHORT SWEEP
ROM_NTRI       .equ     BASE+$1DA00     ; Triangle w/NOISE
ROM_DELTA      .equ     BASE+$1DC00     ; Positive spike
ROM_NOISE      .equ     BASE+$1DE00     ; Guess

* JERRY Registers (DSP)

D_FLAGS        .equ     BASE+$1A100     ; DSP Flags
D_MTXC         .equ     BASE+$1A104     ; DSP Matrix Control
D_MTXA         .equ     BASE+$1A108     ; DSP Matrix Address
D_END          .equ     BASE+$1A10C     ; DSP Data Organization
D_PC           .equ     BASE+$1A110     ; DSP Program Counter
D_CTRL         .equ     BASE+$1A114     ; DSP Operation Control/Status
D_MOD          .equ     BASE+$1A118     ; DSP Modulo Instruction Mask
D_REMAIN       .equ     BASE+$1A11C     ; DSP Division Remainder
D_DIVCTRL      .equ     BASE+$1A11C     ; DSP Divider control
D_MACHI        .equ     BASE+$1A120     ; DSP Hi byte of MAC operations
D_RAM          .equ     BASE+$1B000     ; DSP Internal RAM
D_ENDRAM       .equ     D_RAM +(8*1024) ; 8K bytes


* JERRY Flag Register.equates

D_CPUENA       .equ     $00000010       ; CPU Interrupt Enable Bit
D_I2SENA       .equ     $00000020       ; I2S Interrupt Enable Bit
D_TIM1ENA      .equ     $00000040       ; Timer 1 Interrupt Enable Bit
D_TIM2ENA      .equ     $00000080       ; Timer 2 Interrupt Enable Bit
D_EXT0ENA      .equ     $00000100       ; External Interrupt 0 Enable Bit
D_EXT1ENA      .equ     $00010000       ; External Interrupt 1 Enable Bit

D_CPUCLR       .equ     $00000200       ; CPU Interrupt Clear Bit
D_I2SCLR       .equ     $00000400       ; I2S Interrupt Clear Bit
D_TIM1CLR      .equ     $00000800       ; Timer 1 Interrupt Clear Bit
D_TIM2CLR      .equ     $00001000       ; Timer 2 Interrupt Clear Bit
D_EXT0CLR      .equ     $00002000       ; External Interrupt 0 Clear Bit
D_EXT1CLR      .equ     $00020000       ; External Interrupt 1 Clear Bit

* JERRY Control/Status Register

DSPGO          .equ     $00000001       ; Start DSP
DSPINT0        .equ     $00000004       ; Generate a DSP Interrupt 0

D_CPULAT       .equ     $00000040       ; Interrupt Latches
D_I2SLAT       .equ     $00000080
D_TIM1LAT      .equ     $00000100
D_TIM2LAT      .equ     $00000200
D_EXT1LAT      .equ     $00000400
D_EXT2LAT      .equ     $00010000

* JERRY Modulo Instruction Masks

MODMASK2       .equ     $FFFFFFFE       ; 2 byte circular buffer
MODMASK4       .equ     $FFFFFFFC       ; 4 byte circular buffer
MODMASK8       .equ     $FFFFFFF8       ; 8 byte circular buffer
MODMASK16      .equ     $FFFFFFF0       ; 16 byte circular buffer
MODMASK32      .equ     $FFFFFFE0       ; 32 byte circular buffer
MODMASK64      .equ     $FFFFFFC0       ; 64 byte circular buffer
MODMASK128     .equ     $FFFFFF80       ; 128 byte circular buffer
MODMASK256     .equ     $FFFFFF00       ; 256 byte circular buffer
MODMASK512     .equ     $FFFFFE00       ; 512 byte circular buffer
MODMASK1K      .equ     $FFFFFC00       ; 1k circular buffer
MODMASK2K      .equ     $FFFFF800       ; 2k circular buffer
MODMASK4K      .equ     $FFFFF000       ; 4k circular buffer
MODMASK8K      .equ     $FFFFE000       ; 8k circular buffer
MODMASK16K     .equ     $FFFFC000       ; 16k circular buffer
MODMASK32K     .equ     $FFFF8000       ; 32k circular buffer
MODMASK64K     .equ     $FFFF0000       ; 64k circular buffer
MODMASK128K    .equ     $FFFE0000       ; 128k circular buffer
MODMASK256K    .equ     $FFFC0000       ; 256k circular buffer
MODMASK512K    .equ     $FFF80000       ; 512k circular buffer
MODMASK1M      .equ     $FFF00000       ; 1M circular buffer

* SHARED.equates for TOM (GPU) and JERRY (DSP)

* Control/Status Registers

RISCGO         .equ     $00000001       ; Start GPU or DSP
CPUINT         .equ     $00000002       ; Allow the GPU/DSP to interrupt CPU
FORCEINT0      .equ     $00000004       ; Cause an INT 0 on GPU or DSP
SINGLE_STEP    .equ     $00000008       ; Enter SINGLE_STEP mode
SINGLE_GO      .equ     $00000010       ; Execute one instruction

REGPAGE        .equ     $00004000       ; Register Bank Select
DMAEN          .equ     $00008000       ; Enable DMA LOAD and STORE

* Flags Register

ZERO_FLAG      .equ     $00000001       ; ALU Zero Flag
CARRY_FLAG     .equ     $00000002       ; ALU Carry Flag
NEGA_FLAG      .equ     $00000004       ; ALU Negative Flag

IMASK          .equ     $00000008       ; Interrupt Service Mask

* Matrix Control Register

MATRIX3        .equ     $00000003       ; use for 3x1 Matrix
MATRIX4        .equ     $00000004       ; etc...
MATRIX5        .equ     $00000005
MATRIX6        .equ     $00000006
MATRIX7        .equ     $00000007
MATRIX8        .equ     $00000008
MATRIX9        .equ     $00000009
MATRIX10       .equ     $0000000A
MATRIX11       .equ     $0000000B
MATRIX12       .equ     $0000000C
MATRIX13       .equ     $0000000D
MATRIX14       .equ     $0000000E
MATRIX15       .equ     $0000000F

MATROW         .equ     $00000000       ; Access Matrix by Row
MATCOL         .equ     $00000010       ; Access Matrix by Column

* Data Organisation Register

BIG_IO         .equ     $00010001       ; Use 32-bit registers as big-endian
BIG_PIX        .equ     $00020002       ; Pixel organisation is big-endian
BIG_INST       .equ     $00040004       ; Word program fetches are big-endian

* Divide Unit Control

DIV_OFFSET     .equ     $00000001       ; Divide 16.16 values if set


;;;
;;; These registers should never be messed with so these.equs will
;;; be purged in the next revision of JAGUAR.INC. Please don't use them.
;;;

MEMCON1        .equ     BASE+0  ; Memory Configuration Register One
MEMCON2        .equ     BASE+2  ; Memory Configuration Register Two
OLPLO          .equ     BASE+$20
OLPHI          .equ     BASE+$22
ODP            .equ     BASE+$24        ; Object Data Pointer
HP             .equ     BASE+$2e        ; Horizontal Period
HBB            .equ     BASE+$30        ; Horizontal Blanking Begin
HBE            .equ     BASE+$32        ; Horizontal Blanking End
HS             .equ     BASE+$34        ; Horizontal Sync
HVS            .equ     BASE+$36        ; Horizontal Vertical Sync
VP             .equ     BASE+$3e        ; Vertical Period
VBB            .equ     BASE+$40        ; Vertical Blanking Begin
VBE            .equ     BASE+$42        ; Vertical Blanking End
VEB            .equ     BASE+$4a        ; Vertical.equalization Begin
VEE            .equ     BASE+$4c        ; Vertical.equalization End
HEQ            .equ     BASE+$54        ; Horizontal.equalization End
TEST1          .equ     BASE+$56        ; Undocumented Register - DO NOT USE

R_DAC          .equ     BASE+$1A148     ; These are not connected in Jaguar
L_DAC          .equ     BASE+$1A14C     ; so DO NOT USE!!!

* offsets for each object in the user object list

O_XPOS         .equ     0               ; word object xpos
O_YPOS         .equ     O_XPOS+2        ; word object ypos in half lines
O_DATA         .equ     O_YPOS+2        ; long phrase aligned RAM address of object data
O_HEIGHT       .equ     O_DATA+4        ; word height of object in pixels
O_DWIDTH       .equ     O_HEIGHT+2      ; word phrases per line of data in object (bytes per line / 8)
O_IWIDTH       .equ     O_DWIDTH+2      ; word phrases per line (bytes per line / 8)
                                        ;       this is how many phrases of data to draw per line
                                        ;       this should be the same as O_DWIDTH to draw the whole object
O_FLAGS        .equ     O_IWIDTH+2      ; byte  flags for reflect, RMW, transparent, release
                                        ;       settings for bits in O_FLAGS byte
HFLIP_OFF      .equ     0
HFLIP_ON       .equ     1               ; bit 0 = horizontal flip (reflect)
RMW_OFF        .equ     0
RMW_ON         .equ     2               ; bit 1 = RMW flag
TRANS_OFF      .equ     0
TRANS_ON       .equ     4               ; bit 2 = transparent flag
RELEASE_OFF    .equ     0
RELEASE_ON     .equ     8               ; bit 3 = release

O_FIRSTPIX     .equ     O_FLAGS+1       ; byte first pixel to be displayed in one line of an object
                                        ;       pixels to skip = O_FIRSTPIX / bits per pixel
O_TYPE         .equ     O_FIRSTPIX+1    ; byte object type
                                        ;       0 = bit mapped object
                                        ;       1 = scaled bit mapped object
                                        ;       2 = graphics processor object
                                        ;       3 = branch object
                                        ;       4 = stop object
DELETE_OBJ     .equ     $80             ; if negative bit is set in O_TYPE
                                        ;       object is not included in the final object list

O_DEPTH        .equ     O_TYPE+1        ; byte pixel depth
                                        ;       0 = 1 bit per pixel
                                        ;       1 = 2 bits per pixel
                                        ;       2 = 4 bits per pixel
                                        ;       3 = 8 bits per pixel
                                        ;       4 = 16 bits per pixel (CRY)
                                        ;       5 = 24 bits per pixel
O_PITCH        .equ     O_DEPTH+1       ; byte pitch
                                        ;       how many phrases to skip each time a new phrase is fetched
                                        ;       0 = repeat the same phrase
                                        ;       1 = contiguous data
                                        ;       2 = get every other phrase
                                        ;       3 = get every third phrase, etc.
O_INDEX        .equ     O_PITCH+1       ; byte palette index
                                        ;       4 bits per pixel objects can use 0 - 120 (multiples of 8 only)
                                        ;       2 bits per pixel objects can use 0 - 126 (multiples of 2 only)
                                        ;       1 bit  per pixel objects can use 0 - 127
                                        ; starting color number will be index * 2
O_DESC         .equ     O_INDEX+1       ; word object description (can be set to anything by user - this is not used by object list builder)
O_SCALE        .equ     O_DESC+2        ; long scaling information to write in 2nd long of phrase 3
                                        ;       1st byte is unused
O_REMAINDER    .equ     O_SCALE+1       ; 2nd byte is remainder, same as vscale
O_VSCALE       .equ     O_REMAINDER+1   ; 3rd byte is vscale, 3 bits + 5 bit fraction
O_HSCALE       .equ     O_VSCALE+1      ; 4th byte is hscale, 3 bits + 5 bit fraction

O_ROM          .equ     O_SCALE+4       ; ROM address of object image
O_MODE         .equ     O_ROM+4         ; Object flags
OBJSIZE        .equ     O_MODE+4        ; total bytes used for one object


* MODE VALUES

M_EMPTY        .equ     $00000000       ; inactive or empty Object
M_ACTIVE       .equ     $00000001       ; Active Object
M_UNUSED1      .equ     $00000002       ; Moveable Object
M_UNUSED2      .equ     $00000004       ; Seperatable Object action
M_UNUSED3      .equ     $00000008       ; left-hand piece (special case)
M_UNUSED4      .equ     $00000010       ; unused
M_UNUSED5      .equ     $00000020       ; unused
M_UNUSED6      .equ     $00000040       ; unused
M_UNUSED7      .equ     $00000080       ; unused
M_UNUSED8      .equ     $00000100       ; unused
M_UNUSED9      .equ     $00000200       ; unused
M_UNUSED10     .equ     $00000400       ; unused
M_UNUSED11     .equ     $00000800       ; unused
M_UNUSED12     .equ     $00001000       ; unused
M_UNUSED13     .equ     $00002000       ; unused
M_UNUSED14     .equ     $00004000       ; unused
M_UNUSED15     .equ     $00008000       ; unused
M_UNUSED16     .equ     $00010000       ; unused
M_UNUSED17     .equ     $00020000       ; unused
M_UNUSED18     .equ     $00040000       ; unused
M_UNUSED19     .equ     $00080000       ; unused
M_UNUSED20     .equ     $00100000       ; unused
M_UNUSED21     .equ     $00200000       ; unused
M_UNUSED22     .equ     $00400000       ; unused
M_UNUSED23     .equ     $00800000       ; unused
M_UNUSED24     .equ     $01000000       ; unused
M_UNUSED25     .equ     $02000000       ; unused
M_UNUSED26     .equ     $04000000       ; unused
M_UNUSED27     .equ     $08000000       ; unused
M_UNUSED28     .equ     $10000000       ; unused
M_UNUSED29     .equ     $20000000       ; unused
M_UNUSED30     .equ     $40000000       ; unused
M_UNUSED31     .equ     $80000000       ; unused

* OBJECT IDs and OFFSETS


BITSIZE        .equ     (16>>3)         ; phrase offset
SCBITSIZE      .equ     (32>>3)
GPUSIZE        .equ     (8>>3)
BRANCHSIZE     .equ     (8>>3)
STOPSIZE       .equ     (8>>3)
